@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ from tencentcloud.apigateway.v20180808 import models
 
 class ApigatewayClient(AbstractClient):
     _apiVersion = '2018-08-08'
-    _endpoint = 'apigateway.tencentcloudapi.com'
+    _endpoint = 'apigateway.intl.tencentcloudapi.com'
     _service = 'apigateway'
 
 
@@ -913,7 +913,6 @@ class ApigatewayClient(AbstractClient):
     def DescribeApiKeysStatus(self, request):
         """This API is used to query the information of one or more API keys.
 
-
         :param request: Request instance for DescribeApiKeysStatus.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeApiKeysStatusRequest`
         :rtype: :class:`tencentcloud.apigateway.v20180808.models.DescribeApiKeysStatusResponse`
@@ -981,6 +980,29 @@ class ApigatewayClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeExclusiveInstanceRegions(self, request):
+        """Get the list of supported regions for dedicated instances
+
+        :param request: Request instance for DescribeExclusiveInstanceRegions.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeExclusiveInstanceRegionsRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.DescribeExclusiveInstanceRegionsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeExclusiveInstanceRegions", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeExclusiveInstanceRegionsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeIPStrategy(self, request):
         """This API is used to query IP policy details.
 
@@ -1050,6 +1072,29 @@ class ApigatewayClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeInstancesNetworkConfig(self, request):
+        """This API is used to obtain the network configuration list of a dedicated instance.
+
+        :param request: Request instance for DescribeInstancesNetworkConfig.
+        :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeInstancesNetworkConfigRequest`
+        :rtype: :class:`tencentcloud.apigateway.v20180808.models.DescribeInstancesNetworkConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeInstancesNetworkConfig", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeInstancesNetworkConfigResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeLogSearch(self, request):
         """This API is used to search for logs.
 
