@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,10 +22,33 @@ from tencentcloud.billing.v20180709 import models
 
 class BillingClient(AbstractClient):
     _apiVersion = '2018-07-09'
-    _endpoint = 'billing.tencentcloudapi.com'
+    _endpoint = 'billing.intl.tencentcloudapi.com'
     _service = 'billing'
 
 
+    def CreateAllocationRule(self, request):
+        """Create a sharing rule.
+
+        :param request: Request instance for CreateAllocationRule.
+        :type request: :class:`tencentcloud.billing.v20180709.models.CreateAllocationRuleRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.CreateAllocationRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAllocationRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAllocationRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAllocationTag(self, request):
         """This API is used to batch set cost allocation tags.
 
@@ -49,6 +72,75 @@ class BillingClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAllocationUnit(self, request):
+        """This API is used to create allocation units.
+
+        :param request: Request instance for CreateAllocationUnit.
+        :type request: :class:`tencentcloud.billing.v20180709.models.CreateAllocationUnitRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.CreateAllocationUnitResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAllocationUnit", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAllocationUnitResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateGatherRule(self, request):
+        """Create a collection rule.
+
+        :param request: Request instance for CreateGatherRule.
+        :type request: :class:`tencentcloud.billing.v20180709.models.CreateGatherRuleRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.CreateGatherRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateGatherRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateGatherRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteAllocationRule(self, request):
+        """Delete sharing rule interface.
+
+        :param request: Request instance for DeleteAllocationRule.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DeleteAllocationRuleRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DeleteAllocationRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAllocationRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAllocationRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteAllocationTag(self, request):
         """u200cThis API is used to batch cancel cost allocation tags.
 
@@ -72,6 +164,52 @@ class BillingClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteAllocationUnit(self, request):
+        """Delete a cost allocation unit.
+
+        :param request: Request instance for DeleteAllocationUnit.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DeleteAllocationUnitRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DeleteAllocationUnitResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAllocationUnit", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAllocationUnitResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteGatherRule(self, request):
+        """Delete a collection rule.
+
+        :param request: Request instance for DeleteGatherRule.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DeleteGatherRuleRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DeleteGatherRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteGatherRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteGatherRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAccountBalance(self, request):
         """This API is used to check the Tencent Cloud account balance.
 
@@ -95,6 +233,121 @@ class BillingClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAllocationRuleDetail(self, request):
+        """This API is used to query sharing rule details.
+
+        :param request: Request instance for DescribeAllocationRuleDetail.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeAllocationRuleDetailRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeAllocationRuleDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAllocationRuleDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAllocationRuleDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeAllocationRuleSummary(self, request):
+        """This API is used to query all sharing rule overviews.
+
+        :param request: Request instance for DescribeAllocationRuleSummary.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeAllocationRuleSummaryRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeAllocationRuleSummaryResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAllocationRuleSummary", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAllocationRuleSummaryResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeAllocationTree(self, request):
+        """This API is used to query the cost tree.
+
+        :param request: Request instance for DescribeAllocationTree.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeAllocationTreeRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeAllocationTreeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAllocationTree", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAllocationTreeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeAllocationUnitDetail(self, request):
+        """Query the details of a cost allocation unit.
+
+        :param request: Request instance for DescribeAllocationUnitDetail.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeAllocationUnitDetailRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeAllocationUnitDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAllocationUnitDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAllocationUnitDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeBillAdjustInfo(self, request):
+        """This API is used to check whether the current UIN has any adjustment, enabling customers to proactively obtain the adjustment status faster.
+
+        :param request: Request instance for DescribeBillAdjustInfo.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeBillAdjustInfoRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeBillAdjustInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBillAdjustInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBillAdjustInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeBillDetail(self, request):
         """u200cThis API is used to get bill details.
         Note:
@@ -513,6 +766,29 @@ class BillingClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDealsByCond(self, request):
+        """Querying orders
+
+        :param request: Request instance for DescribeDealsByCond.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeDealsByCondRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeDealsByCondResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDealsByCond", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDealsByCondResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDosageCosDetailByDate(self, request):
         """This API is used to query COS usage details.
 
@@ -536,6 +812,29 @@ class BillingClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeGatherRuleDetail(self, request):
+        """This API is used to query the collection rule details.
+
+        :param request: Request instance for DescribeGatherRuleDetail.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeGatherRuleDetailRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeGatherRuleDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeGatherRuleDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeGatherRuleDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeTagList(self, request):
         """This API is used to get cost allocation tags.
 
@@ -598,6 +897,75 @@ class BillingClient(AbstractClient):
             model = models.DescribeVoucherUsageDetailsResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyAllocationRule(self, request):
+        """Edit sharing rules.
+
+        :param request: Request instance for ModifyAllocationRule.
+        :type request: :class:`tencentcloud.billing.v20180709.models.ModifyAllocationRuleRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.ModifyAllocationRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAllocationRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAllocationRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyAllocationUnit(self, request):
+        """This API is used to modify cost allocation unit information.
+
+        :param request: Request instance for ModifyAllocationUnit.
+        :type request: :class:`tencentcloud.billing.v20180709.models.ModifyAllocationUnitRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.ModifyAllocationUnitResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAllocationUnit", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAllocationUnitResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyGatherRule(self, request):
+        """Edit a collection rule.
+
+        :param request: Request instance for ModifyGatherRule.
+        :type request: :class:`tencentcloud.billing.v20180709.models.ModifyGatherRuleRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.ModifyGatherRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyGatherRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyGatherRuleResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
