@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ from tencentcloud.cfw.v20190904 import models
 
 class CfwClient(AbstractClient):
     _apiVersion = '2019-09-04'
-    _endpoint = 'cfw.tencentcloudapi.com'
+    _endpoint = 'cfw.intl.tencentcloudapi.com'
     _service = 'cfw'
 
 
@@ -854,6 +854,29 @@ class CfwClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeVpcAcRule(self, request):
+        """Query Inter-VPC rules
+
+        :param request: Request instance for DescribeVpcAcRule.
+        :type request: :class:`tencentcloud.cfw.v20190904.models.DescribeVpcAcRuleRequest`
+        :rtype: :class:`tencentcloud.cfw.v20190904.models.DescribeVpcAcRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeVpcAcRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeVpcAcRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ExpandCfwVertical(self, request):
         """This API is used to increase the firewall bandwidth.
 
