@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -221,6 +221,9 @@ INVALIDPARAMETER_INVALIDMETATYPE = 'InvalidParameter.InvalidMetaType'
 # Invalid target specification.
 INVALIDPARAMETER_INVALIDMODIFYSPEC = 'InvalidParameter.InvalidModifySpec'
 
+# Illegal node count.
+INVALIDPARAMETER_INVALIDNODECOUNT = 'InvalidParameter.InvalidNodeCount'
+
 # Incorrect node type.
 INVALIDPARAMETER_INVALIDNODEFLAG = 'InvalidParameter.InvalidNodeFlag'
 
@@ -305,6 +308,9 @@ INVALIDPARAMETER_INVALIDTIMEUNIT = 'InvalidParameter.InvalidTimeUnit'
 # The TKE cluster ID is invalid, or the TKE cluster is not eligible.
 INVALIDPARAMETER_INVALIDTKEINSTANCE = 'InvalidParameter.InvalidTkeInstance'
 
+# Parent account UIN parameter input error.
+INVALIDPARAMETER_INVALIDUINNUM = 'InvalidParameter.InvalidUinNum'
+
 # Invalid unified metadatabase.
 INVALIDPARAMETER_INVALIDUNIFYMETA = 'InvalidParameter.InvalidUnifyMeta'
 
@@ -362,6 +368,9 @@ RESOURCEINSUFFICIENT_DISKINSUFFICIENT = 'ResourceInsufficient.DiskInsufficient'
 # The node specification is unsupported or has been sold out.
 RESOURCEINSUFFICIENT_INSTANCEINSUFFICIENT = 'ResourceInsufficient.InstanceInsufficient'
 
+# Resources do not exist.
+RESOURCENOTFOUND = 'ResourceNotFound'
+
 # The instance was not found.
 RESOURCENOTFOUND_CLUSTERNOTFOUND = 'ResourceNotFound.ClusterNotFound'
 
@@ -389,6 +398,9 @@ RESOURCENOTFOUND_TAGSNOTFOUND = 'ResourceNotFound.TagsNotFound'
 # There is no default value of the current resource spec.
 RESOURCEUNAVAILABLE_RESOURCESPECNOTDEFAULTSPEC = 'ResourceUnavailable.ResourceSpecNotDefaultSpec'
 
+# The resource specification does not exist.
+RESOURCEUNAVAILABLE_RESOURCESPECNOTEXIST = 'ResourceUnavailable.ResourceSpecNotExist'
+
 # The resources have been sold out.
 RESOURCESSOLDOUT = 'ResourcesSoldOut'
 
