@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ from tencentcloud.iai.v20200303 import models
 
 class IaiClient(AbstractClient):
     _apiVersion = '2020-03-03'
-    _endpoint = 'iai.tencentcloudapi.com'
+    _endpoint = 'iai.intl.tencentcloudapi.com'
     _service = 'iai'
 
 
@@ -294,7 +294,6 @@ class IaiClient(AbstractClient):
         >
         - Please use the signature algorithm v3 to calculate the signature in the common parameters, that is, set the `SignatureMethod` parameter to `TC3-HMAC-SHA256`.
 
-
         :param request: Request instance for DetectFace.
         :type request: :class:`tencentcloud.iai.v20200303.models.DetectFaceRequest`
         :rtype: :class:`tencentcloud.iai.v20200303.models.DetectFaceResponse`
@@ -358,6 +357,30 @@ class IaiClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DetectFaceSimilarity(self, request):
+        """Compare the faces in the two pictures for similarity and return the face similarity score. If you need to determine "whether this person is someone", that is, to verify whether the person in a picture is someone with a known identity, such as a common face login scenario, it is recommended to use [VerifyFace] (https://www.tencentcloud.com/document/product/1059/36972) or [VerifyPerson] (https://www.tencentcloud.com/document/product/1059/36971) inferface.
+        Please use the V3 version for the signature method in the public parameters, that is, configure the SignatureMethod parameter to TC3-HMAC-SHA256
+
+        :param request: Request instance for DetectFaceSimilarity.
+        :type request: :class:`tencentcloud.iai.v20200303.models.DetectFaceSimilarityRequest`
+        :rtype: :class:`tencentcloud.iai.v20200303.models.DetectFaceSimilarityResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DetectFaceSimilarity", params, headers=headers)
+            response = json.loads(body)
+            model = models.DetectFaceSimilarityResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DetectLiveFace(self, request):
         """This API is used to detect the liveness of a face in a static image uploaded by a user. Compared with dynamic liveness detection, static liveness detection does not require moving lips, shaking head, or blinking for recognition.
 
