@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,10 +22,34 @@ from tencentcloud.mps.v20190612 import models
 
 class MpsClient(AbstractClient):
     _apiVersion = '2019-06-12'
-    _endpoint = 'mps.tencentcloudapi.com'
+    _endpoint = 'mps.intl.tencentcloudapi.com'
     _service = 'mps'
 
 
+    def BatchProcessMedia(self, request):
+        """This API is used to initiate batch processing tasks for URL video links, with features including:
+        Smart subtitle (full speech, speech hotword, and speech translation)
+
+        :param request: Request instance for BatchProcessMedia.
+        :type request: :class:`tencentcloud.mps.v20190612.models.BatchProcessMediaRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.BatchProcessMediaResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("BatchProcessMedia", params, headers=headers)
+            response = json.loads(body)
+            model = models.BatchProcessMediaResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAIAnalysisTemplate(self, request):
         """This API is used to create a custom content analysis template. Up to 50 templates can be created.
 
@@ -118,6 +142,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAsrHotwords(self, request):
+        """This API is used to create a smart subtitle hotword lexicon.
+
+        :param request: Request instance for CreateAsrHotwords.
+        :type request: :class:`tencentcloud.mps.v20190612.models.CreateAsrHotwordsRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.CreateAsrHotwordsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAsrHotwords", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAsrHotwordsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateContentReviewTemplate(self, request):
         """This API is used to create a custom content moderation template. Up to 50 templates can be created in total.
 
@@ -164,6 +211,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateLiveRecordTemplate(self, request):
+        """This API is used to create a live recording template.
+
+        :param request: Request instance for CreateLiveRecordTemplate.
+        :type request: :class:`tencentcloud.mps.v20190612.models.CreateLiveRecordTemplateRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.CreateLiveRecordTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateLiveRecordTemplate", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateLiveRecordTemplateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreatePersonSample(self, request):
         """This API is used to create image samples for video processing operations such as content recognition and inappropriate information detection with the help of technologies such as facial feature positioning.
 
@@ -267,6 +337,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateSmartSubtitleTemplate(self, request):
+        """This API is used to create a custom smart subtitle template.
+
+        :param request: Request instance for CreateSmartSubtitleTemplate.
+        :type request: :class:`tencentcloud.mps.v20190612.models.CreateSmartSubtitleTemplateRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.CreateSmartSubtitleTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateSmartSubtitleTemplate", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateSmartSubtitleTemplateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateSnapshotByTimeOffsetTemplate(self, request):
         """This API is used to create a custom time point screencapturing template. Up to 16 templates can be created.
 
@@ -487,6 +580,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteAsrHotwords(self, request):
+        """This API is used to delete a smart subtitle hotword lexicon.
+
+        :param request: Request instance for DeleteAsrHotwords.
+        :type request: :class:`tencentcloud.mps.v20190612.models.DeleteAsrHotwordsRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.DeleteAsrHotwordsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAsrHotwords", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAsrHotwordsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteContentReviewTemplate(self, request):
         """This API is used to delete a custom content moderation template.
 
@@ -533,6 +649,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteLiveRecordTemplate(self, request):
+        """This API is used to delete a live recording template.
+
+        :param request: Request instance for DeleteLiveRecordTemplate.
+        :type request: :class:`tencentcloud.mps.v20190612.models.DeleteLiveRecordTemplateRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.DeleteLiveRecordTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteLiveRecordTemplate", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteLiveRecordTemplateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeletePersonSample(self, request):
         """This API is used to delete image samples by image ID.
 
@@ -625,6 +764,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteSmartSubtitleTemplate(self, request):
+        """This API is used to delete a user-defined smart subtitle template.
+
+        :param request: Request instance for DeleteSmartSubtitleTemplate.
+        :type request: :class:`tencentcloud.mps.v20190612.models.DeleteSmartSubtitleTemplateRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.DeleteSmartSubtitleTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteSmartSubtitleTemplate", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteSmartSubtitleTemplateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteSnapshotByTimeOffsetTemplate(self, request):
         """This API is used to delete a custom time point screencapturing template.
 
@@ -832,6 +994,75 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAsrHotwords(self, request):
+        """This API is used to query a smart subtitle hotword lexicon.
+
+        :param request: Request instance for DescribeAsrHotwords.
+        :type request: :class:`tencentcloud.mps.v20190612.models.DescribeAsrHotwordsRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.DescribeAsrHotwordsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAsrHotwords", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAsrHotwordsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeAsrHotwordsList(self, request):
+        """This API is used to obtain the hotword lexicon list.
+
+        :param request: Request instance for DescribeAsrHotwordsList.
+        :type request: :class:`tencentcloud.mps.v20190612.models.DescribeAsrHotwordsListRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.DescribeAsrHotwordsListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAsrHotwordsList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAsrHotwordsListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeBatchTaskDetail(self, request):
+        """This API is used to query the details of the task execution status and results by task ID (tasks submitted within the last 7 days can be queried).
+
+        :param request: Request instance for DescribeBatchTaskDetail.
+        :type request: :class:`tencentcloud.mps.v20190612.models.DescribeBatchTaskDetailRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.DescribeBatchTaskDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBatchTaskDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBatchTaskDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeContentReviewTemplates(self, request):
         """This API is used to query content moderation templates by template ID. Both custom and preset templates that match the template IDs passed in will be returned.
 
@@ -878,6 +1109,52 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeImageTaskDetail(self, request):
+        """This API is used to query the details of the task execution status and results by task ID (tasks submitted within the last 7 days can be queried).
+
+        :param request: Request instance for DescribeImageTaskDetail.
+        :type request: :class:`tencentcloud.mps.v20190612.models.DescribeImageTaskDetailRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.DescribeImageTaskDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeImageTaskDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeImageTaskDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeLiveRecordTemplates(self, request):
+        """This API is used to get a live recording template.
+
+        :param request: Request instance for DescribeLiveRecordTemplates.
+        :type request: :class:`tencentcloud.mps.v20190612.models.DescribeLiveRecordTemplatesRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.DescribeLiveRecordTemplatesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeLiveRecordTemplates", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeLiveRecordTemplatesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeMediaMetaData(self, request):
         """This API is used to get the metadata of media, such as video image width/height, codec, length, and frame rate.
 
@@ -993,6 +1270,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeSmartSubtitleTemplates(self, request):
+        """This API is used to obtain the list of smart subtitle templates based on template unique identifier. The returned result includes all matching user-defined smart subtitle templates and system preset smart subtitle templates.
+
+        :param request: Request instance for DescribeSmartSubtitleTemplates.
+        :type request: :class:`tencentcloud.mps.v20190612.models.DescribeSmartSubtitleTemplatesRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.DescribeSmartSubtitleTemplatesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSmartSubtitleTemplates", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSmartSubtitleTemplatesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeSnapshotByTimeOffsetTemplates(self, request):
         """This API is used to query the list of time point screencapturing templates and supports paged queries by filters.
 
@@ -1016,6 +1316,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeStreamLinkSecurityGroup(self, request):
+        """This API is used to query a security group.
+
+        :param request: Request instance for DescribeStreamLinkSecurityGroup.
+        :type request: :class:`tencentcloud.mps.v20190612.models.DescribeStreamLinkSecurityGroupRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.DescribeStreamLinkSecurityGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeStreamLinkSecurityGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeStreamLinkSecurityGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeTaskDetail(self, request):
         """This API is used to query the details of execution status and result of a task submitted in the last 3 days by task ID.
 
@@ -1423,6 +1746,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyAsrHotwords(self, request):
+        """This API is used to update a smart subtitle hotword lexicon.
+
+        :param request: Request instance for ModifyAsrHotwords.
+        :type request: :class:`tencentcloud.mps.v20190612.models.ModifyAsrHotwordsRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.ModifyAsrHotwordsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAsrHotwords", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAsrHotwordsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyContentReviewTemplate(self, request):
         """This API is used to modify a custom content moderation template.
 
@@ -1469,6 +1815,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyLiveRecordTemplate(self, request):
+        """This API is used to modify a live recording template.
+
+        :param request: Request instance for ModifyLiveRecordTemplate.
+        :type request: :class:`tencentcloud.mps.v20190612.models.ModifyLiveRecordTemplateRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.ModifyLiveRecordTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyLiveRecordTemplate", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyLiveRecordTemplateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyPersonSample(self, request):
         """This API is used to modify image samples by image ID. You can use it to modify the name and description of an image sample and add/delete/reset facial features or tags. There must be at least one image left after the deletion of facial features; otherwise, please reset instead of delete the facial features.
 
@@ -1561,6 +1930,29 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifySmartSubtitleTemplate(self, request):
+        """This API is used to modify a user-defined smart subtitle template.
+
+        :param request: Request instance for ModifySmartSubtitleTemplate.
+        :type request: :class:`tencentcloud.mps.v20190612.models.ModifySmartSubtitleTemplateRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.ModifySmartSubtitleTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifySmartSubtitleTemplate", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifySmartSubtitleTemplateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifySnapshotByTimeOffsetTemplate(self, request):
         """This API is used to modify a custom time point screencapturing template.
 
@@ -1701,6 +2093,32 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ProcessImage(self, request):
+        """This API is used to initiate image processing, with features including:
+        1. Format conversion.
+        2. Image enhancement.
+        3. Image erasure.
+
+        :param request: Request instance for ProcessImage.
+        :type request: :class:`tencentcloud.mps.v20190612.models.ProcessImageRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.ProcessImageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ProcessImage", params, headers=headers)
+            response = json.loads(body)
+            model = models.ProcessImageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ProcessLiveStream(self, request):
         """This API is used to initiate live stream processing tasks. Such tasks may include the following:
 
@@ -1733,19 +2151,20 @@ class MpsClient(AbstractClient):
 
 
     def ProcessMedia(self, request):
-        """This API is used to initiate a processing task for video URLs or media files in Cloud Object Storage (COS). Features include:
-        1. Video transcoding (standard transcoding, TSC transcoding, and audio/video enhancement);
-        2. Animated image generating;
-        3. Screenshot taking at specified time points;
-        4. Sampled screenshot taking;
-        5. Sprite screenshot taking;
-        6. Transcoding to adaptive bitrate streaming;
-        7. Intelligent auditing (porn detection and sensitive information detection);
-        8. Intelligent analysis (tagging, classification, thumbnail generating, frame-by-frame tagging, video splitting, highlights generating, opening and closing segments recognition, and game timestamping);
-        9. Intelligent identification (face, full text, text keyword, full speech, speech keyword, speech translation, and object recognition);
-
+        """This API is used to initiate a processing task for video URLs or media files in COS. Features include:
+        1. Video transcoding (standard transcoding, TSC transcoding, and audio/video enhancement).
+        2. Video-to-GIF conversion.
+        3. Time point screenshot of videos.
+        4. Sampled screenshot of videos.
+        5. Image sprite of videos.
+        6. Adaptive bitrate stream conversion for videos.
+        7. Intelligent content moderation (pornography detection and sensitive information detection).
+        8. Intelligent content analysis (tag, category, cover, frame tag, video splitting, highlight, opening and ending clips, and game tracking).
+        9. Intelligent content recognition (human face, full text, text keyword, full speech, speech keyword, speech translation, and object).
         10. Media quality inspection (live stream format diagnosis, audio and video content detection (jitter, blur, low light, overexposure, black and white edges, black and white screens, screen glitch, noise, mosaic, QR code, and more), and no-reference scoring).
 
+        11. Smart subtitle (full speech, speech hotword, and speech translation).
+
         :param request: Request instance for ProcessMedia.
         :type request: :class:`tencentcloud.mps.v20190612.models.ProcessMediaRequest`
         :rtype: :class:`tencentcloud.mps.v20190612.models.ProcessMediaResponse`
