@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ from tencentcloud.sqlserver.v20180328 import models
 
 class SqlserverClient(AbstractClient):
     _apiVersion = '2018-03-28'
-    _endpoint = 'sqlserver.tencentcloudapi.com'
+    _endpoint = 'sqlserver.intl.tencentcloudapi.com'
     _service = 'sqlserver'
 
 
@@ -141,8 +141,31 @@ class SqlserverClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateBasicDBInstances(self, request):
+        """This API is used to create basic edition instances (cloud disk).
+
+        :param request: Request instance for CreateBasicDBInstances.
+        :type request: :class:`tencentcloud.sqlserver.v20180328.models.CreateBasicDBInstancesRequest`
+        :rtype: :class:`tencentcloud.sqlserver.v20180328.models.CreateBasicDBInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateBasicDBInstances", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateBasicDBInstancesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateBusinessDBInstances(self, request):
-        """This API is used to create a business intelligence service instance.
+        """This API is used to create business intelligence service instances (cloud disk).
 
         :param request: Request instance for CreateBusinessDBInstances.
         :type request: :class:`tencentcloud.sqlserver.v20180328.models.CreateBusinessDBInstancesRequest`
@@ -188,7 +211,7 @@ class SqlserverClient(AbstractClient):
 
 
     def CreateCloudDBInstances(self, request):
-        """This API is used to create a high-availability instance of cloud disk edition.
+        """This API is used to create high-availability instances (cloud disk).
 
         :param request: Request instance for CreateCloudDBInstances.
         :type request: :class:`tencentcloud.sqlserver.v20180328.models.CreateCloudDBInstancesRequest`
@@ -211,7 +234,7 @@ class SqlserverClient(AbstractClient):
 
 
     def CreateCloudReadOnlyDBInstances(self, request):
-        """This API is used to add a read-only replica instance of cloud disk edition.
+        """This API is used to create read-only instances (cloud disk).
 
         :param request: Request instance for CreateCloudReadOnlyDBInstances.
         :type request: :class:`tencentcloud.sqlserver.v20180328.models.CreateCloudReadOnlyDBInstancesRequest`
@@ -257,7 +280,7 @@ class SqlserverClient(AbstractClient):
 
 
     def CreateDBInstances(self, request):
-        """This API is used to create an instance.
+        """This API is used to create high-availability instances (local disk).
 
         :param request: Request instance for CreateDBInstances.
         :type request: :class:`tencentcloud.sqlserver.v20180328.models.CreateDBInstancesRequest`
@@ -325,6 +348,29 @@ class SqlserverClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateReadOnlyDBInstances(self, request):
+        """This API is used to create read-only instances (local disk).
+
+        :param request: Request instance for CreateReadOnlyDBInstances.
+        :type request: :class:`tencentcloud.sqlserver.v20180328.models.CreateReadOnlyDBInstancesRequest`
+        :rtype: :class:`tencentcloud.sqlserver.v20180328.models.CreateReadOnlyDBInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateReadOnlyDBInstances", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateReadOnlyDBInstancesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteAccount(self, request):
         """This API is used to delete an instance account.
 
@@ -877,6 +923,29 @@ class SqlserverClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeMaintenanceSpan(self, request):
+        """This API is used to query the maintenance time window of an instance based on its instance ID.
+
+        :param request: Request instance for DescribeMaintenanceSpan.
+        :type request: :class:`tencentcloud.sqlserver.v20180328.models.DescribeMaintenanceSpanRequest`
+        :rtype: :class:`tencentcloud.sqlserver.v20180328.models.DescribeMaintenanceSpanResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeMaintenanceSpan", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeMaintenanceSpanResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeMigrationDetail(self, request):
         """This API is used to query migration task details.
 
@@ -992,6 +1061,29 @@ class SqlserverClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeRestoreTimeRange(self, request):
+        """This API is used to query the time range available for rollback by time point.
+
+        :param request: Request instance for DescribeRestoreTimeRange.
+        :type request: :class:`tencentcloud.sqlserver.v20180328.models.DescribeRestoreTimeRangeRequest`
+        :rtype: :class:`tencentcloud.sqlserver.v20180328.models.DescribeRestoreTimeRangeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeRestoreTimeRange", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeRestoreTimeRangeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeRollbackTime(self, request):
         """This API is used to query the time range available for instance rollback.
 
@@ -1384,6 +1476,29 @@ class SqlserverClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyDReadable(self, request):
+        """This API is used to enable or disable the read-only feature of the replica server.
+
+        :param request: Request instance for ModifyDReadable.
+        :type request: :class:`tencentcloud.sqlserver.v20180328.models.ModifyDReadableRequest`
+        :rtype: :class:`tencentcloud.sqlserver.v20180328.models.ModifyDReadableResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyDReadable", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyDReadableResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyDatabaseCDC(self, request):
         """This API is used to enable or disable the change data capture (CDC) feature.
 
